==> api-0.16.0-sources.jar: io/strimzi/api/kafka/model/template/ExternalServiceTemplateFluent.java <==
package io.strimzi.api.kafka.model.template;

import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.fabric8.kubernetes.api.builder.Predicate;
import java.lang.StringBuffer;
import java.lang.Deprecated;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

public interface ExternalServiceTemplateFluent<A extends ExternalServiceTemplateFluent<A>> extends Fluent<A>{


    
/**
 * This method has been deprecated, please use method buildMetadata instead.
 * @return The buildable object.
 */
@Deprecated public MetadataTemplate getMetadata();
    public MetadataTemplate buildMetadata();
    public A withMetadata(MetadataTemplate metadata);
    public Boolean hasMetadata();
    public ExternalServiceTemplateFluent.MetadataNested<A> withNewMetadata();
    public ExternalServiceTemplateFluent.MetadataNested<A> withNewMetadataLike(MetadataTemplate item);
    public ExternalServiceTemplateFluent.MetadataNested<A> editMetadata();
    public ExternalServiceTemplateFluent.MetadataNested<A> editOrNewMetadata();
    public ExternalServiceTemplateFluent.MetadataNested<A> editOrNewMetadataLike(MetadataTemplate item);
    public ExternalTrafficPolicy getExternalTrafficPolicy();
    public A withExternalTrafficPolicy(ExternalTrafficPolicy externalTrafficPolicy);
    public Boolean hasExternalTrafficPolicy();
    public A addToLoadBalancerSourceRanges(int index,String item);
    public A setToLoadBalancerSourceRanges(int index,String item);
    public A addToLoadBalancerSourceRanges(String... items);
    public A addAllToLoadBalancerSourceRanges(Collection<String> items);
    public A removeFromLoadBalancerSourceRanges(String... items);
    public A removeAllFromLoadBalancerSourceRanges(Collection<String> items);
    public List<String> getLoadBalancerSourceRanges();
    public String getLoadBalancerSourceRange(int index);
    public String getFirstLoadBalancerSourceRange();
    public String getLastLoadBalancerSourceRange();
    public String getMatchingLoadBalancerSourceRange(io.fabric8.kubernetes.api.builder.Predicate<String> predicate);
    public Boolean hasMatchingLoadBalancerSourceRange(io.fabric8.kubernetes.api.builder.Predicate<String> predicate);
    public A withLoadBalancerSourceRanges(List<String> loadBalancerSourceRanges);
    public A withLoadBalancerSourceRanges(String... loadBalancerSourceRanges);
    public Boolean hasLoadBalancerSourceRanges();
    public A addNewLoadBalancerSourceRange(String arg1);
    public A addNewLoadBalancerSourceRange(StringBuilder arg1);
    public A addNewLoadBalancerSourceRange(StringBuffer arg1);

    public interface MetadataNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,MetadataTemplateFluent<ExternalServiceTemplateFluent.MetadataNested<N>>{

        
    public N and();    public N endMetadata();
}


}

==> api-0.21.0-sources.jar: io/strimzi/api/kafka/model/template/ExternalServiceTemplateFluent.java <==
package io.strimzi.api.kafka.model.template;

import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.fabric8.kubernetes.api.builder.Predicate;
import java.lang.StringBuffer;
import java.lang.Deprecated;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

public interface ExternalServiceTemplateFluent<A extends ExternalServiceTemplateFluent<A>> extends Fluent<A>{


    
/**
 * This method has been deprecated, please use method buildMetadata instead.
 * @return The buildable object.
 */
@Deprecated public MetadataTemplate getMetadata();
    public MetadataTemplate buildMetadata();
    public A withMetadata(MetadataTemplate metadata);
    public Boolean hasMetadata();
    public ExternalServiceTemplateFluent.MetadataNested<A> withNewMetadata();
    public ExternalServiceTemplateFluent.MetadataNested<A> withNewMetadataLike(MetadataTemplate item);
    public ExternalServiceTemplateFluent.MetadataNested<A> editMetadata();
    public ExternalServiceTemplateFluent.MetadataNested<A> editOrNewMetadata();
    public ExternalServiceTemplateFluent.MetadataNested<A> editOrNewMetadataLike(MetadataTemplate item);
    public ExternalTrafficPolicy getExternalTrafficPolicy();
    public A withExternalTrafficPolicy(ExternalTrafficPolicy externalTrafficPolicy);
    public Boolean hasExternalTrafficPolicy();
    public A addToLoadBalancerSourceRanges(int index,String item);
    public A setToLoadBalancerSourceRanges(int index,String item);
    public A addToLoadBalancerSourceRanges(String... items);
    public A addAllToLoadBalancerSourceRanges(Collection<String> items);
    public A removeFromLoadBalancerSourceRanges(String... items);
    public A removeAllFromLoadBalancerSourceRanges(Collection<String> items);
    public java.util.List<String> getLoadBalancerSourceRanges();
    public String getLoadBalancerSourceRange(int index);
    public String getFirstLoadBalancerSourceRange();
    public String getLastLoadBalancerSourceRange();
    public String getMatchingLoadBalancerSourceRange(io.fabric8.kubernetes.api.builder.Predicate<String> predicate);
    public Boolean hasMatchingLoadBalancerSourceRange(io.fabric8.kubernetes.api.builder.Predicate<String> predicate);
    public A withLoadBalancerSourceRanges(java.util.List<String> loadBalancerSourceRanges);
    public A withLoadBalancerSourceRanges(String... loadBalancerSourceRanges);
    public Boolean hasLoadBalancerSourceRanges();
    public A addNewLoadBalancerSourceRange(String arg1);
    public A addNewLoadBalancerSourceRange(StringBuilder arg1);
    public A addNewLoadBalancerSourceRange(StringBuffer arg1);

    public interface MetadataNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,MetadataTemplateFluent<ExternalServiceTemplateFluent.MetadataNested<N>>{

        
    public N and();    public N endMetadata();
}


}
